@@ -43,10 +43,12 @@ export class Fleet extends Construct {
       runtime: lambda.Runtime.PYTHON_3_9,
       layers: [this.signalCatalog.lambdaLayer],
       role: this.signalCatalog.lambdaRole,
+      logRetention: this.signalCatalog.logRetention,
     });
 
     const provider = new cr.Provider(this, 'Provider', {
       onEventHandler: onEventHandler,
+      logRetention: this.signalCatalog.logRetention,
     });
 
     const resource = new cdk.CustomResource(this, 'Resource', {
@@ -54,7 +56,7 @@ export class Fleet extends Construct {
       properties: {
         fleet_id: this.fleetId,
         signal_catalog_arn: this.signalCatalog.arn,
-        description: props.description,
+        description: props.description || ' ',
         vehicle_ids: this.vehicles!.map(v => v.vehicleId),
       },
     });
